SQLAlchemy 2.0 Future (Core) — SQLAlchemy 2.0 Documentation

Release: 2.0.1 | Release Date: February 1, 2023

# SQLAlchemy 2.0 Documentation

# SQLAlchemy 2.0 Future (Core)

We’re 2.0!

This page described the “future” mode provided in SQLAlchemy 1.4 for the purposes of 1.4 -> 2.0 transition. For 2.0, the “future” parameter on `create_engine()` and `Session` continues to remain available for backwards-compatibility support, however if specified must be left at the value of `True`.

See also

SQLAlchemy 2.0 - Major Migration Guide - Introduction to the 2.0 series of SQLAlchemy